### ----------------------------------------
### Tick-pathogen model Rstanarm
### NPS tick drag data 2014-2022
### Code created by A. Martin
### Email: alynn.martin89@gmail.com
### ----------------------------------------
### MODEL03 Pathogen and deer density


### L O A D   P A C K A G E S

library(rstanarm)
library(rstan)
library(bayesrules)
library(tidyverse)
library(bayesplot)
library(tidybayes)



### L O A D  D A T A

data03 <- read.table(file="XXX.txt")  ## load tabular data using download name



### M O D E L  03

stan_mod03 <- stan_glmer(
  
  cbind(number_bbss_positive, number_bbss_negative) ~ palmerz_may + relative_humidity_april + relative_humidity_may + (1|park_id) + lagged_deer_density,

  data=data03, 
  
  family=binomial(link = "logit"), 
  
  prior_intercept = normal(0,2.0),
  
  prior = normal(0,2.0), 
  
  prior_covariance = decov(reg = 1, conc = 1, shape = 1, scale = 1),
  
  importance_resampling=TRUE, keep_every=10,

  chains = 3, iter = 30000*2, seed = 1000

  )



###  M O D E L   O U T P U T

## summary

summary(stan_mod03)

coef(stan_mod03)

stan_mod03$coefficients

tidy(stan_mod03, effects = "fixed", conf.int = TRUE, conf.level = 0.95)

tidy(stan_mod03, effects = "ran_vals", conf.int = TRUE, conf.level = 0.95)


## trace plots

trace <- plot(stan_mod03, "trace", pars=(c("(Intercept)", "palmerz_may", "relative_humidity_april", "relative_humidity_may", "lagged_deer_density")))


## plotting fixed variable effect

plot(stan_mod03, pars =c("(Intercept)", "palmerz_may", "relative_humidity_april", "relative_humidity_may", "lagged_deer_density"), prob=0.5, prob_outer=0.95)

